/*
 *	Incremental search
 *	Copyright
 *		(C) 1992 Joseph H. Allen
 *
 *	This file is part of JOE (Joe's Own Editor)
 */
#ifndef _JOE_UISRCH_H
#define _JOE_UISRCH_H 1

int uisrch PARAMS((BW *bw));
int ursrch PARAMS((BW *bw));

#endif
